#
# spec file for package python-datadiff
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-datadiff
Version:        2.2.0
Release:        4.9
Summary:        DataDiff is a library to provide human-readable diffs of python data structures
License:        Apache-2.0
URL:            https://sourceforge.net/projects/datadiff/
#Source:         https://files.pythonhosted.org/packages/source/d/datadiff/datadiff-%%{version}.tar.gz
#Git-Clone:     https://git.code.sf.net/p/datadiff/code
Source:         datadiff-%{version}.tar.xz
# PATCH-FIX-UPSTREAM https://sourceforge.net/p/datadiff/code/merge-requests/3/
Patch0:         python-datadiff-no-six.patch
# PATCH-FIX-UPSTREAM https://sourceforge.net/p/datadiff/code/merge-requests/4/
Patch1:         support-python312.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION

%python_subpackages

%description
DataDiff is a library to provide human-readable diffs of python data structures.
It can handle sequence types (lists, tuples, etc), sets, and dictionaries.
Dictionaries and sequences will be diffed recursively, when applicable.
It has special-case handling for multi-line strings, showing them as a typical unified diff.
Drop-in replacements for some nose assertions are available.  If the assertion fails,
a nice data diff is shown, letting you easily pinpoint the root difference.

%prep
%autosetup -p1 -n datadiff-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%{python_sitelib}/datadiff
%{python_sitelib}/datadiff-%{version}.dist-info

%changelog
* Wed Jan 10 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-python312.patch:
  * In Python 3.12, slice() is now hashable, use a class that isn't hashable.
- Switch to pyproject macros.
* Tue Oct  3 2023 pgajdos@suse.com
- Update to version 2.2.0:
  * Bump version
  * Removed separate version file now that Setuptools can read without importing.
  * Ran ruff --fix to clean up some lint.
  * Remove LICENSE from MANIFEST.in (Setuptools includes it by default now).
  * Add a pyproject.toml for better packaging support.
  * Mark failing tests as xfail until someone can investigate.
  * Moved package metadata to declarative setup.cfg
  * Remove tests_require
  * Remove superfluous license field
  * Remove commented code for deprecated usage.
  * Port test runner to nose.
- added patches
  https://sourceforge.net/p/datadiff/code/merge-requests/3/
  + python-datadiff-no-six.patch
- dropped switch-to-pytest.patch (merged upstream)
* Wed Mar 22 2023 daniel.garcia@suse.com
- Fix the version in the package, it was set to 2.2.0, but the version
  provided was 2.0.0.
- Disable broken tests with python 3.11, related to ordering of sets
- Remove six dependency
- Update to version 2.1.0:
  * Bump version
  * Seems like this is never used
  * Better exception testing pattern, better test coverage :)
  * Remove python <2.6 stuff; and an adhoc nose test runner
  * Only round, not convert to hashable, when comparing dict values
  * Coverage reporting
  * PEP8 and other good practice fixes
  * Add LICENSE file, build wheels
  * Move tests into package subdir
  * Add tox.ini and test against more versions of python
  * fix __bool__ case when dict only has equal type diffs
  * fuzzy matching for float comparisons, fix empty set diffs
  * test_hashable_dict_values
  * revert datadiff/tools.py hashable to maintain module_nose.tools compatibility
  * use hashable when comparing
* Thu Sep 16 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add patch switch-to-pytest.patch:
  * Stop using nose imports, use pytest instead.
* Mon Oct 21 2019 Martin Hauke <mardnh@gmx.de>
- Add license file LICENSE-2.0.txt
  * Project is licenced under Apache-2.0
    see: setup.py
* Tue Oct  1 2019 mardnh@gmx.de
- Initial package, version 2.0.0
